| Title: | Analysis of Ladybird Occurrence Data |
|---|---|
| Description: | Analysis of ladybird occurrence data from Belgium, the Netherlands and the UK since 1990. |
| Authors: | Thierry Onkelinx [aut, cre] (ORCID: <https://orcid.org/0000-0001-8804-4216>), Tim Adriaens [aut] (ORCID: <https://orcid.org/0000-0001-7268-4200>), Dirk Maes [aut] (ORCID: <https://orcid.org/0000-0002-7947-3788>), Research Institute for Nature and Forest [cph, fnd] |
| Maintainer: | Thierry Onkelinx <[email protected]> |
| License: | GPL-3 |
| Version: | 0.0.2 |
| Built: | 2026-05-09 08:47:53 UTC |
| Source: | https://github.com/inbo/ladybird |
Fit a base model to a species
base_model( species = "Harm_axyr", min_occurrences = 1000, min_species = 3, first_order = TRUE, center_year = 2001 )base_model( species = "Harm_axyr", min_occurrences = 1000, min_species = 3, first_order = TRUE, center_year = 2001 )
species |
Name of the species. |
min_occurrences |
The minimum number of occurrences per species. |
min_species |
The minimum number of species recorded at the combination of location and year. |
first_order |
Use first ( |
center_year |
The year to center to.
Defaults to |
Fit a model to a species using the cumulative predictions for a secundary species
cumulative_model( species = "Adal_bipu", min_occurrences = 1000, min_species = 3, secondary, first_order = TRUE, center_year = 2001 )cumulative_model( species = "Adal_bipu", min_occurrences = 1000, min_species = 3, secondary, first_order = TRUE, center_year = 2001 )
species |
Name of the species. |
min_occurrences |
The minimum number of occurrences per species. |
min_species |
The minimum number of species recorded at the combination of location and year. |
secondary |
The output of |
first_order |
Use first ( |
center_year |
The year to center to.
Defaults to |
Fit a model to a species using the predictions for a secondary species
fit_model(first_order = TRUE, base_data, trend_prediction, base_prediction)fit_model(first_order = TRUE, base_data, trend_prediction, base_prediction)
first_order |
Use first ( |
base_data |
A dataframe with the base data. |
trend_prediction |
A dataframe with the timestamps to predict the trend. |
base_prediction |
A dataframe with the locations and timestamps to predict. |
Import and standardise the raw data
import_data(belgium, output, strict = TRUE)import_data(belgium, output, strict = TRUE)
belgium |
path to the CSV file with the Belgian data. |
output |
path to the root of the data package |
strict |
What to do when the metadata changes. |
Load the relevant occurrence data
load_relevant(min_occurrences = 1000, min_species = 3)load_relevant(min_occurrences = 1000, min_species = 3)
min_occurrences |
The minimum number of occurrences per species. |
min_species |
The minimum number of species recorded at the combination of location and year. |
Display a leaflet map with the occurrences for a given species
occurrence_map()occurrence_map()
Fit a model to a species using the predictions for a secondary species
probability_model( species = "Adal_dece", min_occurrences = 1000, min_species = 3, secondary, first_order = TRUE, center_year = 2001 )probability_model( species = "Adal_dece", min_occurrences = 1000, min_species = 3, secondary, first_order = TRUE, center_year = 2001 )
species |
Name of the species. |
min_occurrences |
The minimum number of occurrences per species. |
min_species |
The minimum number of species recorded at the combination of location and year. |
secondary |
The output of |
first_order |
Use first ( |
center_year |
The year to center to.
Defaults to |